@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 our $PANDOC_VERSION;    # a string like '1.16'
 $PANDOC_VERSION ||= $ENV{PANDOC_VERSION};
@@ -72,7 +72,10 @@ use Scalar::Util qw(blessed reftype);
 use Pandoc::Walker qw(walk);
 
 use parent 'Exporter';
-our @EXPORT = ( keys %ELEMENTS, qw(Document attributes citation pandoc_json) );
+our @EXPORT = (
+    keys %ELEMENTS,
+    qw(Document attributes metadata citation pandoc_json)
+);
 our @EXPORT_OK = ( @EXPORT, 'element' );
 
 # create constructor functions
@@ -100,12 +103,12 @@ foreach my $name ( keys %ELEMENTS ) {
     );
 
     for ( my $i = 0 ; $i < @accessors ; $i++ ) {
-        my $code = @accessors == 1 ? "\$_[0]->{c}" : "\$_[0]->{c}->[$i]";
-
+        my $member = @accessors == 1 ? "\$e->{c}" : "\$e->{c}->[$i]";
+        my $code = "my \$e = shift; $member = ( 1 == \@_ ? \$_[0] : [\@_] ) if \@_; return";
         # auto-bless on access via accessor (TODO: move to constructor?)
-        if ( $accessors[$i] =~ s/:\[(.+)\]$// ) {
-            $code = "[ map { bless \$_, 'Pandoc::Document::$1' } \@{$code} ]";
-        }
+        $code .= $accessors[$i] =~ s/:\[(.+)\]$//
+        ? " [ map { bless \$_, 'Pandoc::Document::$1' } \@{$member} ];"
+        : " $member;";
         for ( split '/', $accessors[$i] ) {
             *{ $class . "::$_" } = eval "sub { $code }";
         }
@@ -122,7 +125,8 @@ sub element {
 
 sub Document($$) {
     @_ == 2 or croak "Document expects 2 arguments, but given " . scalar @_;
-    return bless [ { unMeta => $_[0] }, $_[1] ], 'Pandoc::Document';
+    my $meta = metadata(shift);
+    return bless [ { unMeta => $meta }, shift ], 'Pandoc::Document';
 }
 
 # specific accessors
@@ -155,6 +159,10 @@ sub citation($) {
     };
 }
 
+sub metadata($) {
+    $_[0]; # TODO: issue #10 and #34
+}
+
 sub pandoc_json($) {
     state $ast_to_element = sub {   # compile once, use repeatedly, keep private
         my $class = 'Pandoc::Document::' . $_[0]->{t};
@@ -201,10 +209,13 @@ sub pandoc_json($) {
     package Pandoc::Document;
     use strict;
     our $VERSION = '0.04';
-    our @ISA     = ('Pandoc::Document::Element');
-    sub name        { 'Document' }
-    sub meta        { $_[0]->[0]->{unMeta} }
-    sub content     { $_[0]->[1] }
+    our @ISA = ('Pandoc::Document::Element');
+    sub name { 'Document' }
+    sub meta {
+        $_[0]->[0]->{unMeta} = Pandoc::Elements::metadata($_[1]) if @_ > 1;
+        $_[0]->[0]->{unMeta}
+    }
+    sub content { $_[0]->[1] }
     sub is_document { 1 }
     sub metavalue {
         my $meta = $_[0]->meta;
