@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use JSON;
 use Carp;
@@ -33,6 +33,9 @@ sub pandoc_walk(@) {    ## no critic
 }
 
 sub pandoc_filter(@) {    ## no critic
+    require Pandoc::Filter::Usage;
+    Pandoc::Filter::Usage::frompod();
+
     my $ast = pandoc_walk(@_);    # implies binmode STDOUT UTF-8
     my $json = JSON->new->allow_blessed->convert_blessed->encode($ast);
 
@@ -40,6 +43,16 @@ sub pandoc_filter(@) {    ## no critic
     say STDOUT $json;
 }
 
+# build_image( $element [, $filename ] )
+#
+# Maps an element to an L<Image|Pandoc::Elements/Image> element with attributes
+# from the given element. The attribute C<caption>, if available, is transformed
+# into image caption. This utility function is useful for filters that transform
+# content to images. See graphviz, tikz, lilypond and similar filters in the
+# L<examples|https://metacpan.org/pod/distribution/Pandoc-Elements/examples/>.
+#
+# This function will be (re)moved during further refactoring
+
 sub build_image {
     my $e = shift;
     my $filename = shift // '';
@@ -191,23 +204,9 @@ Read a single line of JSON from STDIN and walk down the document content AST
 =head2 pandoc_filter( @actions | %actions )
 
 Read a single line of JSON from STDIN, apply actions on the document content
-and print the resulting AST as single line of JSON. This function is roughly
-equivalent to
-
-    my $ast    = Pandoc::Elements::pandoc_json(<>);
-    my $format = $ARGV[0];
-    Pandoc::Filter->new(@actions)->apply($ast->content, $format, $ast->meta);
-    say $ast->to_json;
-
-=head2 build_image( $element [, $filename ] )
-
-Maps an element to an L<Image|Pandoc::Elements/Image> element with attributes
-from the given element. The attribute C<caption>, if available, is transformed
-into image caption. This utility function is useful for filters that transform
-content to images. See graphviz, tikz, lilypond and similar filters in the
-L<examples|https://metacpan.org/pod/distribution/Pandoc-Elements/examples/>.
-
-This function is I<experimental> and may be (re)move in a later version!
+and print the resulting AST as single line of JSON. L<Pandoc::Filter::Usage>
+is used to print filter documentation if called with command line argument
+C<--help>, C<-h>, or C<-?> instead.
 
 =head1 SEE ALSO
 
